import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClose function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Alert message="Warning Text" type="warning" closable onClose={fn} />);
 * alert.fireClose(container);
 * expect(fn).toBeCalled();
 */
export declare function fireClose(container: IContainer): void;
/**
 * Returns the `index` container of Alert
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Alert message="Warning Text1" data-testid="test1" />
 *         <Alert message="Warning Text2" data-testid="test2" />
 *     </>
 * );
 * expect(alert.query(container)).toEqual(getByTestId('test1'));
 * expect(alert.query(container, 1)).toEqual(getByTestId('test2'));
 * alert.query(container, 1);
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = HTMLElement | null;
