import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function
 * @param indexOrHash the specific link index or hashname
 * @example
 * const fn = jest.fn();
 * const items = [
 *     { title: 'a', href: '#a', key: 'a' },
 *     { title: 'b', href: '#b', key: 'b' },
 * ];
 * const { container } = render(<Anchor onClick={fn} items={items} />);
 * anchor.fireClick(container, '#a');
 * expect(fn.mock.calls[0]?.[1]).toMatchObject({ title: 'a', href: '#a' });
 * anchor.fireClick(container, 1);
 * expect(fn.mock.calls[1]?.[1]).toMatchObject({ title: 'b', href: '#b' });
 */
export declare function fireClick(container: IContainer, indexOrHash?: string | number): void;
/**
 * Returns the `index` container of Anchor
 * @param index default is `0`
 * @example
 * const { container } = render(
 *     <>
 *         <Anchor className="test1" items={[{ title: 'a', key: 'a', href: '#a' }]} />
 *         <Anchor className="test2" items={[{ title: 'a', key: 'a', href: '#a' }]} />
 *     </>
 * );
 * expect(anchor.query(container)?.className).toContain('test1');
 * expect(anchor.query(container, 1)?.className).toContain('test2');
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` item of Anchor link
 * @param index default is `0`
 * @example
 * const items = [
 *     { title: 'a', href: '#a', key: 'a' },
 *     { title: 'b', href: '#b', key: 'b' },
 * ];
 * const { container, getByTitle } = render(<Anchor items={items} />);
 * expect(anchor.queryLink(container)).toEqual(getByTitle('a'));
 * expect(anchor.queryLink(container, 1)).toEqual(getByTitle('b'));
 */
export declare function queryLink(container: IContainer, index?: number): QueryLinkReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryLink: typeof queryLink;
        fireClick: typeof fireClick;
    }> | null | undefined;
type QueryLinkReturnElement = MixinElement<{
        query: typeof query;
        queryLink: typeof queryLink;
        fireClick: typeof fireClick;
    }> | null | undefined;
