import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onMouseEnter function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Radio onMouseEnter={fn}>Radio</Radio>);
 *
 *         radio.fireMouseEnter(container);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireMouseEnter(container: IContainer): void;
/**
 * Fires onMouseLeave function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <Radio.Group onMouseLeave={fn}>
 *                 <Radio value={1}>A</Radio>
 *             </Radio.Group>
 *         );
 *
 *         radio.fireMouseLeave(container);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireMouseLeave(container: IContainer): void;
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <Radio.Group onChange={fn} defaultValue={1}>
 *                 <Radio value="A">A</Radio>
 *                 <Radio value="B">B</Radio>
 *             </Radio.Group>
 *         );
 *
 *         radio.fireChange(container, 1);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireChange(container: IContainer, index: number): void;
/**
 * Returns the wrapper element for each Radio
 * @example
 * const { container } = render(<Radio>Radio</Radio>);
 * expect(radio.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the group element
 * @example
 * const { container } = render(<Radio.Group options={['Apple', 'Pear', 'Orange']} />);
 * expect(radio.queryGroup(container)).not.toBeNull();
 */
export declare function queryGroup(container: IContainer, index?: number): QueryGroupReturnElement;
/**
 * Returns the input element in Radio
 * @example
 * const { container } = render(<Radio.Group options={['Apple', 'Pear', 'Orange']} />);
 * expect(radio.queryInput(container)).not.toBeNull();
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireMouseEnter: typeof fireMouseEnter;
        fireMouseLeave: typeof fireMouseLeave;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryGroupReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireMouseEnter: typeof fireMouseEnter;
        fireMouseLeave: typeof fireMouseLeave;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireMouseEnter: typeof fireMouseEnter;
        fireMouseLeave: typeof fireMouseLeave;
        fireChange: typeof fireChange;
    }> | null | undefined;
