import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Segmented options={['One', 'Two', 'Three']} onChange={fn} />);
 * segmented.fireChange(container, 1);
 * expect(fn).toBeCalledWith('Two');
 */
export declare function fireChange(container: IContainer, index: number): void;
/**
 * Returns the `index` container of Segmented
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Segmented options={[]} data-testid="test1" />
 *         <Segmented options={[]} data-testid="test2" />
 *     </>
 * );
 * expect(segmented.query(container)).toEqual(getByTestId('test1'));
 * expect(segmented.query(container, 1)).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireChange: typeof fireChange;
    }> | null | undefined;
