import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Switch onClick={fn} />);
 *
 *         switchEl.fireClick(container);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireClick(container: IContainer): void;
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Switch onChange={fn} />);
 *
 *         switchEl.fireChange(container);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireChange(container: IContainer): void;
/**
 * Returns the container element
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Switch data-testid="switch1" />
 *         <Switch data-testid="switch2" />
 *     </>
 * );
 * expect(switchEl.query(container)).toBe(getByTestId('switch1'));
 * expect(switchEl.query(container, 1)).toBe(getByTestId('switch2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireClick: typeof fireClick;
        fireChange: typeof fireChange;
    }> | null | undefined;
