import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onOpenChange function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <TimePicker onOpenChange={fn} defaultValue={dateAdaptor('00:00:00', 'HH:mm:ss')} />
 *         );
 *
 *         timePicker.fireOpen(container);
 *         expect(fn).toBeCalled();
 */
export declare function fireOpen(container: IContainer): void;
/**
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <TimePicker
 *                 defaultValue={dateAdaptor('00:00:00', 'HH:mm:ss')}
 *                 onOpenChange={fn}
 *                 getPopupContainer={(node) => node.parentElement!}
 *             />
 *         );
 *
 *         timePicker.fireOpen(container);
 *         timePicker.fireOk(container);
 *         expect(fn).toBeCalled();
 */
export declare function fireOk(container: IContainer): void;
type TimeString = `${string}:${string}:${string}` | `${string}:${string}`;
/**
 * Select a cell
 */
export declare function fireSelectCell(container: IContainer, index: number): void;
/**
 * Fires onChange function
 * @param time give array when RangePicker
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <TimePicker
 *                 onChange={fn}
 *                 getPopupContainer={(node) => node.parentElement!}
 *                 defaultValue={dateAdaptor('00:00:00', 'HH:mm:ss')}
 *             />
 *         );
 *
 *         timePicker.fireOpen(container);
 *         timePicker.fireChange(container, '12:33:44');
 *         expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, time: TimeString | [TimeString, TimeString]): void;
/**
 * Returns the container element
 * @example
 * const { container } = render(<TimePicker getPopupContainer={(node) => node.parentElement!} />);
 * expect(timePicker.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the dropdown of timePicker which is not hidden
 * @example
 * const { container } = render(<TimePicker getPopupContainer={(node) => node.parentElement!} />);
 * timePicker.fireOpen(container);
 * expect(timePicker.queryDropdown(container)).not.toBeNull();
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns the ok button
 * @example
 * const { container } = render(<TimePicker getPopupContainer={(node) => node.parentElement!} />);
 * timePicker.fireOpen(container);
 * expect(timePicker.queryOk(container)).not.toBeNull();
 */
export declare function queryOk(container: IContainer, index?: number): QueryOkReturnElement;
export {};

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryDropdown: typeof queryDropdown;
        queryOk: typeof queryOk;
        fireOpen: typeof fireOpen;
        fireOk: typeof fireOk;
        fireSelectCell: typeof fireSelectCell;
    }> | null | undefined;
type QueryDropdownReturnElement = void;
type QueryOkReturnElement = MixinElement<{
        query: typeof query;
        queryDropdown: typeof queryDropdown;
        queryOk: typeof queryOk;
        fireOpen: typeof fireOpen;
        fireOk: typeof fireOk;
        fireSelectCell: typeof fireSelectCell;
    }> | null | undefined;
