import type { IContainer, MixinElement } from '../interface';
/**
 * Click next step button
 * @example
 * const fn = jest.fn();
 * const { container } = render(<TourDemo onChange={fn} />);
 * button.fireClick(container);
 * tour.fireNextStep(document);
 * expect(fn).toBeCalled();
 */
export declare function fireNextStep(container: IContainer): void;
/**
 * Click prev step button
 * @example
 * const fn = jest.fn();
 * const { container } = render(<TourDemo onChange={fn} />);
 * button.fireClick(container);
 * tour.fireNextStep(document);
 * expect(fn).toHaveBeenLastCalledWith(1);
 * tour.firePrevStep(document);
 * expect(fn).toHaveBeenLastCalledWith(0);
 */
export declare function firePrevStep(container: IContainer): void;
/**
 * Close tour popover
 * @example
 * const fn = jest.fn();
 * const { container } = render(<TourDemo onClose={fn} />);
 * button.fireClick(container);
 * tour.fireClose(document);
 * expect(fn).toBeCalled();
 */
export declare function fireClose(container: IContainer): void;
/**
 * Returns the container of Tour popover
 * @example
 * const { container } = render(<TourDemo />);
 * button.fireClick(container);
 * expect(tour.query(document)).toEqual(document.querySelector('.ant-tour'));
 */
export declare function query(container: IContainer): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        fireNextStep: typeof fireNextStep;
        firePrevStep: typeof firePrevStep;
    }> | null | undefined;
