import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function
 * @example
 * const fn = jest.fn();
 * const items = [{ title: 'Foo' }, { title: 'Bar', onClick: fn }];
 * const { container } = render(<Breadcrumb items={items} />);
 * breadCrumb.fireClick(container, 1);
 * expect(fn).toBeCalled();
 */
export declare function fireClick(container: IContainer, index: number): void;
/**
 * Returns the `index` of Breadcrumb.
 * @param {number} index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Breadcrumb data-testid="test1" />
 *         <Breadcrumb data-testid="test2" />
 *     </>
 * );
 * expect(breadCrumb.query(container)).toBe(getByTestId('test1'));
 * expect(breadCrumb.query(container, 1)).toBe(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` of Breadcrumb Item.
 * @param {number} index default is `0`
 * @example
 * const items = [{ title: 'Foo' }, { title: 'Bar' }];
 *         const { container, queryByText } = render(<Breadcrumb items={items} />);
 *
 *         expect(breadCrumb.queryBreadcrumbItem(container)).toBe(queryByText('Foo'));
 *         expect(breadCrumb.queryBreadcrumbItem(container, 1)).toBe(queryByText('Bar'));
 */
export declare function queryBreadcrumbItem(container: IContainer, index?: number): QueryBreadcrumbItemReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryBreadcrumbItem: typeof queryBreadcrumbItem;
        fireClick: typeof fireClick;
    }> | null | undefined;
type QueryBreadcrumbItemReturnElement = MixinElement<{
        query: typeof query;
        queryBreadcrumbItem: typeof queryBreadcrumbItem;
        fireClick: typeof fireClick;
    }> | null | undefined;
