import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function for Button
 * @example
 * const fn1 = jest.fn();
 *         const fn2 = jest.fn();
 *         const { container } = render(
 *             <>
 *                 <Button onClick={fn1}>Button1</Button>
 *                 <Button onClick={fn2}>Button2</Button>
 *             </>
 *         );
 *         button.fireClick(container);
 *         expect(fn1).toBeCalled();
 *
 *         button.query(container, 1)?.fireClick();
 *         expect(fn2).toBeCalled();
 */
export declare function fireClick(container: IContainer): void;
/**
 * Returns the `index` button that is a descendant of node.
 * @param {number} index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Button data-testid="button1">button1</Button>
 *         <Button data-testid="button2">button2</Button>
 *     </>
 * );
 * expect(button.query(container)).toBe(getByTestId('button1'));
 * expect(button.query(container, 1)).toBe(getByTestId('button2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireClick: typeof fireClick;
    }> | null | undefined;
