import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onTabChange function
 * @param key the key of tab you want click
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Card
 *         tabList={[
 *             { key: 'tab1', tab: 'tab1' },
 *             { key: 'tab2', tab: 'tab2' },
 *         ]}
 *         onTabChange={fn}
 *     />
 * );
 * card.fireTabChange(container, 'tab2');
 * expect(fn).toBeCalledWith('tab2');
 */
export declare function fireTabChange(container: IContainer, key: string): void;
/**
 * Returns the `index` container of Card
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Card data-testid="test1" />
 *         <Card data-testid="test2" />
 *     </>
 * );
 * expect(card.query(container)).toEqual(getByTestId('test1'));
 * expect(card.query(container, 1)).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireTabChange: typeof fireTabChange;
    }> | null | undefined;
