// src/cascader/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { fireClear as selectFireClear, fireOpen as selectFireOpen } from "../select";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector, queryViaSelectors } from "../utils";
var mixins = {
  query,
  querySelect,
  queryInput,
  queryDropdown,
  queryMenu,
  queryMenuItem,
  fireOpen,
  fireChange,
  fireSearch,
  fireClear
};
function fireOpen(container) {
  selectFireOpen(container);
}
function fireChange(container, typeOrIndex, ...rest) {
  var _a, _b;
  const type = typeof typeOrIndex === "string" ? typeOrIndex : "click";
  const indexes = typeof typeOrIndex === "number" ? [typeOrIndex].concat(rest) : rest;
  const triggerEvent = {
    click: "click",
    hover: "mouseEnter"
  };
  for (let i = 0; i < indexes.length; i++) {
    const index = indexes[i];
    const selectors = [
      `ul.${getProvider("prefixCls")}-cascader-menu`,
      `li.${getProvider("prefixCls")}-cascader-menu-item`
    ];
    const ele = queryViaSelectors(container, selectors, [i, index]);
    if (!ele)
      throw failedQuerySelector(selectors.join(" "));
    const last = i === indexes.length - 1;
    (_b = (_a = fireEvent)[last ? "click" : triggerEvent[type]]) == null ? void 0 : _b.call(_a, ele);
  }
}
function fireSearch(container, value) {
  const selector = "input";
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.change(ele, { target: { value } });
}
function fireClear(container) {
  selectFireClear(container);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-cascader`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySelect(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-select-selector`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = "input";
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdown(container) {
  const selector = `.${getProvider("prefixCls")}-cascader-dropdown:not(.${getProvider(
    "prefixCls"
  )}-select-dropdown-hidden)`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryMenu(container, index = 0) {
  const selector = `ul.${getProvider("prefixCls")}-cascader-menu`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryMenuItem(container, index = 0) {
  const selector = `li.${getProvider("prefixCls")}-cascader-menu-item`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireClear,
  fireOpen,
  fireSearch,
  query,
  queryDropdown,
  queryInput,
  queryMenu,
  queryMenuItem,
  querySelect
};
