// src/colorPicker/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryColorPanel,
  queryColorInput,
  queryColorAlphaInput,
  fireChange,
  fireOpen
};
function fireChange(container, color) {
  const selectors = [
    `.${getProvider("prefixCls")}-color-picker:not(.${getProvider("prefixCls")}-popover-hidden) .${getProvider(
      "prefixCls"
    )}-color-picker-input input`,
    `.${getProvider("prefixCls")}-color-picker:not(.${getProvider("prefixCls")}-popover-hidden) .${getProvider(
      "prefixCls"
    )}-color-picker-alpha-input input`
  ];
  if (color.hexColor) {
    const ele = queryColorInput(container);
    if (!ele)
      throw failedQuerySelector(selectors[0]);
    fireEvent.input(ele, { target: { value: color.hexColor } });
  }
  if (color.alpha) {
    const ele = queryColorAlphaInput(container);
    if (!ele)
      throw failedQuerySelector(selectors[1]);
    fireEvent.input(ele, { target: { value: color.alpha } });
  }
}
function fireOpen(container, index = 0, trigger = "click") {
  const selector = `.${getProvider("prefixCls")}-color-picker-trigger`;
  const ele = queryViaSelector(container, selector, index);
  if (!ele)
    throw failedQuerySelector(selector);
  if (trigger === "hover")
    fireEvent.mouseEnter(ele);
  else
    fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-color-picker-trigger`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryColorPanel(container) {
  const selector = `.${getProvider("prefixCls")}-color-picker:not(.${getProvider("prefixCls")}-popover-hidden)`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryColorInput(container) {
  const selector = `.${getProvider("prefixCls")}-color-picker:not(.${getProvider(
    "prefixCls"
  )}-popover-hidden) .${getProvider("prefixCls")}-color-picker-input input`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryColorAlphaInput(container) {
  const selector = `.${getProvider("prefixCls")}-color-picker:not(.${getProvider(
    "prefixCls"
  )}-popover-hidden) .${getProvider("prefixCls")}-color-picker-alpha-input input`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireOpen,
  query,
  queryColorAlphaInput,
  queryColorInput,
  queryColorPanel
};
