// src/datePicker/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, failedTriggerElement, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryInput,
  queryDropdown,
  queryDecadeButton,
  queryMonthButton,
  queryNextButton,
  queryPrevButton,
  queryYearButton,
  querySuperNextButton,
  querySuperPrevButton,
  fireOpen,
  fireClose,
  firePanelChange,
  fireChange,
  fireOk
};
function fireOpen(container) {
  const selector = `.${getProvider("prefixCls")}-picker .${getProvider("prefixCls")}-picker-input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
  fireEvent.focus(ele);
}
function fireClose(container) {
  const selector = `.${getProvider("prefixCls")}-picker-input input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.blur(ele);
}
function firePanelChange(container) {
  const ele = querySuperPrevButton(container) || queryPrevButton(container) || queryNextButton(container) || querySuperNextButton(container) || queryMonthButton(container) || queryYearButton(container) || queryDecadeButton(container);
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
}
function fireChange(container, text) {
  const eles = container.querySelectorAll(
    `.${getProvider("prefixCls")}-picker-dropdown:not(.${getProvider("prefixCls")}-picker-dropdown-hidden) table td`
  );
  const selector = "-in-view";
  const cell = Array.from(eles).find((td) => {
    return td.textContent === String(text) && td.className.includes(selector);
  });
  if (!cell)
    throw failedQuerySelector(`end with ${selector}`);
  fireEvent.click(cell);
}
function fireOk(container) {
  const selector = `.${getProvider("prefixCls")}-picker-ok > *`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-input input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdown(container) {
  const selector = `.${getProvider("prefixCls")}-picker-dropdown:not(${getProvider(
    "prefixCls"
  )}-picker-dropdown-hidden)`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySuperPrevButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-header-super-prev-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryPrevButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-header-prev-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySuperNextButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-header-super-next-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryNextButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-header-next-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDecadeButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-decade-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryYearButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-year-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryMonthButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-month-btn`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireClose,
  fireOk,
  fireOpen,
  firePanelChange,
  query,
  queryDecadeButton,
  queryDropdown,
  queryInput,
  queryMonthButton,
  queryNextButton,
  queryPrevButton,
  querySuperNextButton,
  querySuperPrevButton,
  queryYearButton
};
