// src/dropdown/index.ts
import { act, fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryDropdownMenu,
  queryDropdownMenuItem,
  fireOpen,
  fireSelect
};
function fireCloseWithESC() {
  fireEvent.keyDown(window, { key: "Esc", keyCode: 27 });
}
function fireOpen(container, trigger = "hover") {
  const selector = `.${getProvider("prefixCls")}-dropdown-trigger`;
  const ele = query(container);
  if (!ele)
    throw failedQuerySelector(selector);
  if (trigger === "click") {
    fireEvent.click(ele);
  } else if (trigger === "contextMenu") {
    fireEvent.contextMenu(ele);
  } else {
    fireEvent.mouseEnter(ele);
  }
  act(() => {
    jest.runAllTimers();
  });
}
function fireSelect(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-dropdown-menu-item`;
  const ele = queryViaSelector(container, selector, index);
  if (!ele)
    return failedQuerySelector(selector);
  fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-dropdown-trigger`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdownMenu(container) {
  const selector = `.${getProvider("prefixCls")}-dropdown:not(.${getProvider(
    "prefixCls"
  )}-dropdown-hidden) .${getProvider("prefixCls")}-dropdown-menu`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdownMenuItem(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-dropdown-menu-item`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireCloseWithESC,
  fireOpen,
  fireSelect,
  query,
  queryDropdownMenu,
  queryDropdownMenuItem
};
