import { IContainer, MixinElement } from '../interface';
/**
 * Returns the `index` container of Form
 * @param index default is `0`
 * @example
 * const { container } = render(
 *     <>
 *         <Form name="basic" />
 *         <Form name="advance" />
 *     </>
 * );
 * expect(form.query(container)?.id).toBe('basic');
 * expect(form.query(container, 1)?.id).toBe('advance');
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` form item's element
 * @param index default is `0`
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Form onFinish={fn}>
 *         <Form.Item label="Username" name="username">
 *             <Input />
 *         </Form.Item>
 *         <Form.Item>
 *             <Button htmlType="submit">Submit</Button>
 *         </Form.Item>
 *     </Form>
 * );
 * button.fireClick(form.queryFormItems(container, 1)!);
 * await waitFor(() => {
 *     expect(fn).toBeCalledTimes(1);
 * });
 */
export declare function queryFormItems(container: IContainer, index?: number): QueryFormItemsReturnElement;
/**
 * Returns the `index` form item's control's element
 * @param index default is `0`
 * @example
 * const { container } = render(
 *     <Form>
 *         <Form.Item label="Username" name="username">
 *             <Input />
 *         </Form.Item>
 *     </Form>
 * );
 * expect(form.queryFormItemControls(container)?.querySelector('label')).toBeNull();
 */
export declare function queryFormItemControls(container: IContainer, index?: number): QueryFormItemControlsReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryFormItems: typeof queryFormItems;
        queryFormItemControls: typeof queryFormItemControls;
    }> | null | undefined;
type QueryFormItemsReturnElement = MixinElement<{
        query: typeof query;
        queryFormItems: typeof queryFormItems;
        queryFormItemControls: typeof queryFormItemControls;
    }> | null | undefined;
type QueryFormItemControlsReturnElement = MixinElement<{
        query: typeof query;
        queryFormItems: typeof queryFormItems;
        queryFormItemControls: typeof queryFormItemControls;
    }> | null | undefined;
