// src/input/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
import * as textarea from "./textarea";
var mixins = {
  query,
  querySearchButton,
  fireFocus,
  fireBlur,
  fireChange,
  fireClear,
  firePressEnter,
  fireSearch
};
function fireFocus(container) {
  const selector = "input";
  const inputEl = query(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.focus(inputEl);
}
function fireBlur(container) {
  const selector = "input";
  const inputEl = query(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.blur(inputEl);
}
function fireChange(container, value) {
  const selector = "input";
  const inputEl = query(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.change(inputEl, { target: { value } });
}
function fireClear(container) {
  const selector = `.${getProvider("prefixCls")}-input-clear-icon`;
  const ele = container instanceof HTMLInputElement ? query(container.parentElement) : queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function firePressEnter(container) {
  const selector = "input";
  const inputEl = query(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.keyDown(inputEl, { key: "Enter" });
}
function fireSearch(container) {
  const selector = `.${getProvider("prefixCls")}-input-search-button`;
  const ele = querySearchButton(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `input.${getProvider("prefixCls")}-input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySearchButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-input-search-button`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireBlur,
  fireChange,
  fireClear,
  fireFocus,
  firePressEnter,
  fireSearch,
  query,
  querySearchButton,
  textarea
};
