// src/input/textarea.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, queryViaSelector } from "../utils";
import { fireClear as inputFireClear } from ".";
function fireFocus(container) {
  const selector = `textarea.${getProvider("prefixCls")}-input`;
  const textareaEl = query(container);
  if (!textareaEl)
    throw failedQuerySelector(selector);
  fireEvent.focus(textareaEl);
}
function fireBlur(container) {
  const selector = `textarea.${getProvider("prefixCls")}-input`;
  const textareaEl = query(container);
  if (!textareaEl)
    throw failedQuerySelector(selector);
  fireEvent.blur(textareaEl);
}
function fireChange(container, value) {
  const selector = `textarea.${getProvider("prefixCls")}-input`;
  const textareaEl = query(container);
  if (!textareaEl)
    throw failedQuerySelector(selector);
  fireEvent.change(textareaEl, { target: { value } });
}
function fireClear(container) {
  inputFireClear(container);
}
function firePressEnter(container) {
  const selector = `textarea.${getProvider("prefixCls")}-input`;
  const textareaEl = query(container);
  if (!textareaEl)
    throw failedQuerySelector(selector);
  fireEvent.keyDown(textareaEl, { keyCode: 13 });
}
function query(container, index = 0) {
  const selector = `textarea.${getProvider("prefixCls")}-input`;
  return queryViaSelector(container, selector, index);
}
export {
  fireBlur,
  fireChange,
  fireClear,
  fireFocus,
  firePressEnter,
  query
};
