// src/inputNumber/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryInput,
  fireChange,
  fireStepUp,
  fireStepDown,
  firePressEnter,
  fireFocus,
  fireBlur
};
function fireChange(container, value) {
  const selector = `input.${getProvider("prefixCls")}-input-number-input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.change(ele, { target: { value } });
}
function fireStepUp(container) {
  const selector = `.${getProvider("prefixCls")}-input-number-handler-up`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.mouseDown(ele);
}
function fireStepDown(container) {
  const selector = `.${getProvider("prefixCls")}-input-number-handler-down`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.mouseDown(ele);
}
function firePressEnter(container) {
  const selector = `input.${getProvider("prefixCls")}-input-number`;
  const inputEl = query(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.keyDown(inputEl, { key: "Enter", keyCode: 13, which: 13 });
}
function fireFocus(container) {
  const selector = `input.${getProvider("prefixCls")}-input-number-input`;
  const inputEl = queryInput(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.focus(inputEl);
}
function fireBlur(container) {
  const selector = `input.${getProvider("prefixCls")}-input-number-input`;
  const inputEl = queryInput(container);
  if (!inputEl)
    throw failedQuerySelector(selector);
  fireEvent.blur(inputEl);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-input-number`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = `input.${getProvider("prefixCls")}-input-number-input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireBlur,
  fireChange,
  fireFocus,
  firePressEnter,
  fireStepDown,
  fireStepUp,
  query,
  queryInput
};
