// src/modal/confirm.ts
import { act, fireEvent } from "@testing-library/react";
import * as button from "../button";
import { getProvider } from "../provider";
import { failedTriggerElement, queryViaSelector } from "../utils";
import * as modal from "./";
function fireOpen(ele) {
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
  act(() => {
    jest.runAllTimers();
  });
}
function fireOk(container) {
  const ele = queryOkButton(container);
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
}
function fireCancel(container) {
  const ele = queryCancelButton(container);
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
}
function query3(container, index = 0) {
  return modal.query(container, index);
}
function queryBtns(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-modal-confirm-btns`;
  const ele = queryViaSelector(container, selector, index);
  return ele;
}
function queryCancelButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const btns = queryBtns(container, index);
  if (!btns)
    return null;
  return button.query(btns, 0);
}
function queryOkButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const btns = queryBtns(container, index);
  if (!btns)
    return null;
  return button.query(btns, 1);
}
export {
  fireCancel,
  fireOk,
  fireOpen,
  query3 as query,
  queryBtns,
  queryCancelButton,
  queryOkButton
};
