// src/modal/index.ts
import { fireEvent } from "@testing-library/react";
import * as button from "../button";
import { getProvider } from "../provider";
import { failedTriggerElement, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
import * as confirm from "./confirm";
var mixins = {
  query: query2,
  queryModalFooter,
  queryOkButton,
  queryCancelButton,
  queryMask,
  fireOk,
  fireCancel
};
function fireOk(container) {
  const ele = queryOkButton(container);
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
}
function fireCancel(container) {
  const ele = queryCancelButton(container) || queryMask(container);
  if (!ele)
    throw failedTriggerElement();
  fireEvent.click(ele);
}
function query2(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-modal`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryModalFooter(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-modal-footer`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryCancelButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const ele = queryModalFooter(container, index);
  if (!ele)
    return null;
  return button.query(ele, 0);
}
function queryOkButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const ele = queryModalFooter(container, index);
  if (!ele)
    return null;
  return button.query(ele, 1);
}
function queryMask(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-modal-close`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  confirm,
  fireCancel,
  fireOk,
  query2 as query,
  queryCancelButton,
  queryMask,
  queryModalFooter,
  queryOkButton
};
