// src/pagination/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import * as select from "../select";
import { failedTriggerElement, mixinElementWithTestFuncs, queryViaSelector, queryViaSelectors } from "../utils";
var mixins = {
  query,
  queryNextButton,
  queryPrevButton,
  queryPaginationItem,
  queryJumpNext,
  queryJumpPrev,
  queryQuickJump,
  fireChange,
  fireSizeChange,
  fireSizeOpen
};
function fireSizeOpen(container) {
  select.fireOpen(container);
}
function fireSizeChange(container, index) {
  const dropdown = select.queryDropdown(container);
  if (!dropdown)
    throw failedTriggerElement();
  select.fireSelect(dropdown, index);
}
function fireChange(container, value) {
  if (container instanceof HTMLInputElement) {
    if (!value)
      throw new Error("Call quick jump must pass through value");
    fireEvent.focus(container);
    fireEvent.change(container, { target: { value } });
    fireEvent.blur(container);
  } else {
    const ele = queryNextButton(container) || queryPrevButton(container) || container;
    if (!ele)
      throw failedTriggerElement();
    fireEvent.click(ele);
  }
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-pagination`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryPrevButton(container, index = 0) {
  const selectors = [
    `.${getProvider("prefixCls")}-pagination-prev`,
    `.${getProvider("prefixCls")}-pagination-item-link`
  ];
  const ele = queryViaSelectors(container, selectors, [index]);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryNextButton(container, index = 0) {
  const selectors = [
    `.${getProvider("prefixCls")}-pagination-next`,
    `.${getProvider("prefixCls")}-pagination-item-link`
  ];
  const ele = queryViaSelectors(container, selectors, [index]);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryPaginationItem(container, index) {
  if (index === 0) {
    console.warn("Page number should not start from 0");
    return null;
  }
  const selector = `.${getProvider("prefixCls")}-pagination-item-${index}`;
  const ele = queryViaSelector(container, selector, 0);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryJumpNext(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-pagination-jump-next`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryJumpPrev(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-pagination-jump-prev`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryQuickJump(container, index = 0) {
  const selectors = [`.${getProvider("prefixCls")}-pagination-options-quick-jumper`, "input"];
  const ele = queryViaSelectors(container, selectors, [index]);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireSizeChange,
  fireSizeOpen,
  query,
  queryJumpNext,
  queryJumpPrev,
  queryNextButton,
  queryPaginationItem,
  queryPrevButton,
  queryQuickJump
};
