// src/popconfirm/index.ts
import { act, fireEvent } from "@testing-library/react";
import * as button from "../button";
import { getProvider } from "../provider";
import { failedQuerySelector, failedTriggerElement, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query: query2,
  queryButtons,
  queryCancelButton,
  queryConfirmButton,
  fireCancel,
  fireConfirm
};
function fireOpen(trigger) {
  if (!trigger)
    throw failedTriggerElement();
  jest.runAllTimers();
  act(() => {
    fireEvent.click(trigger);
  });
}
function fireCancel(container) {
  const selector = `.${getProvider("prefixCls")}-popconfirm-buttons .${getProvider("prefixCls")}-btn`;
  const ele = queryCancelButton(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireConfirm(container) {
  const selector = `.${getProvider("prefixCls")}-popconfirm-buttons .${getProvider("prefixCls")}-btn`;
  const ele = queryConfirmButton(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function query2(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-popconfirm`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryButtons(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-popconfirm-buttons`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryCancelButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const ele = queryButtons(container, index);
  if (!ele)
    return null;
  return button.query(ele, 0);
}
function queryConfirmButton(container, index = 0) {
  if (container instanceof HTMLButtonElement) {
    return container;
  }
  const ele = queryButtons(container, index);
  if (!ele)
    return null;
  return button.query(ele, 1);
}
export {
  fireCancel,
  fireConfirm,
  fireOpen,
  query2 as query,
  queryButtons,
  queryCancelButton,
  queryConfirmButton
};
