import type { IContainer, MixinElement } from '../interface';
/**
 * Fires `fireRefresh` function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<QRCode value="http://www.google.com" status="expired" onRefresh={fn} />);
 * qrCode.fireRefresh(container);
 * expect(fn).toBeCalled();
 */
export declare function fireRefresh(container: IContainer, index?: number): void;
/**
 * Returns the `index` container of QRCode
 * @param index defualt is `0`
 * @example
 * const { container } = render(<QRCode value="http://www.google.com" />);
 * expect(qrCode.query(container)).toBeTruthy();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireRefresh: typeof fireRefresh;
    }> | null | undefined;
