// src/radio/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryGroup,
  queryInput,
  fireMouseEnter,
  fireMouseLeave,
  fireChange
};
function fireMouseEnter(container) {
  const ele = queryGroup(container) || query(container);
  if (!ele)
    throw failedQuerySelector("radio");
  fireEvent.mouseEnter(ele);
}
function fireMouseLeave(container) {
  const ele = queryGroup(container) || query(container);
  if (!ele)
    throw failedQuerySelector("radio");
  fireEvent.mouseLeave(ele);
}
function fireChange(container, index) {
  const ele = queryInput(container, index);
  if (!ele)
    throw failedQuerySelector(`input.${getProvider("prefixCls")}-radio-input`);
  fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-radio-wrapper`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryGroup(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-radio-group`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = `input.${getProvider("prefixCls")}-radio-input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireMouseEnter,
  fireMouseLeave,
  query,
  queryGroup,
  queryInput
};
