import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Rate allowHalf onChange={fn} />);
 * rate.fireChange(container, 3);
 * expect(fn).toBeCalledWith(3);
 * rate.fireChange(container, 3.5);
 * expect(fn).lastCalledWith(3.5);
 */
export declare function fireChange(container: IContainer, value: number): void;
/**
 * Fires onHoverChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Rate allowHalf onHoverChange={fn} />);
 * rate.fireHoverChange(container, 3.5);
 * expect(fn).toBeCalledWith(3.5);
 * rate.fireHoverChange(container, 1);
 * expect(fn).lastCalledWith(1);
 */
export declare function fireHoverChange(container: IContainer, value: number): void;
/**
 * Returns the `index` container of Rate
 * @param index default is `0`
 * @example
 * const { container } = render(
 *     <>
 *         <Rate className="test1" />
 *         <Rate className="test2" />
 *     </>
 * );
 * expect(rate.query(container).className).toContain('test1');
 * expect(rate.query(container, 1).className).toContain('test2');
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireChange: typeof fireChange;
        fireHoverChange: typeof fireHoverChange;
    }> | null | undefined;
