// src/select/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector, queryViaSelectors } from "../utils";
var mixins = {
  query,
  queryInput,
  querySelectorWrapper,
  queryDropdown,
  queryOption,
  queryClear,
  fireSearch,
  fireOpen,
  fireSelect,
  fireDeSelect,
  fireFocus,
  fireBlur,
  fireClear
};
function fireSearch(container, value) {
  const selector = `input.${getProvider("prefixCls")}-select-selection-search-input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.change(ele, { target: { value } });
}
function fireOpen(container) {
  const selector = `.${getProvider("prefixCls")}-select-selector`;
  const ele = querySelectorWrapper(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.mouseDown(ele);
}
function fireSelect(container, index) {
  const selector = `div.${getProvider("prefixCls")}-select-item-option-content`;
  const ele = queryOption(container, index);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireDeSelect(container, index) {
  const selectors = [
    `.${getProvider("prefixCls")}-select-selection-item`,
    `.${getProvider("prefixCls")}-select-selection-item-remove`
  ];
  const ele = queryViaSelectors(container, selectors, [index]);
  if (!ele)
    throw failedQuerySelector(`${selectors[0]}[${index}] ${selectors[1]}`);
  fireEvent.click(ele);
}
function fireFocus(container) {
  const selector = `input.${getProvider("prefixCls")}-select-selection-search-input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.focus(ele);
}
function fireBlur(container) {
  const selector = `input.${getProvider("prefixCls")}-select-selection-search-input`;
  const ele = queryInput(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.blur(ele);
}
function fireClear(container) {
  const selector = `.${getProvider("prefixCls")}-select-clear`;
  const ele = queryClear(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.mouseDown(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-select`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = `input.${getProvider("prefixCls")}-select-selection-search-input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySelectorWrapper(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-select-selector`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdown(container) {
  const selector = `.${getProvider("prefixCls")}-select-dropdown:not(.${getProvider(
    "prefixCls"
  )}-select-dropdown-hidden)`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryOption(container, index = 0) {
  const selector = `div.${getProvider("prefixCls")}-select-item-option-content`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryClear(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-select-clear`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireBlur,
  fireClear,
  fireDeSelect,
  fireFocus,
  fireOpen,
  fireSearch,
  fireSelect,
  query,
  queryClear,
  queryDropdown,
  queryInput,
  queryOption,
  querySelectorWrapper
};
