// src/table/index.ts
import { fireEvent } from "@testing-library/react";
import * as checkbox from "../checkbox";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector, queryViaSelectors } from "../utils";
var mixins = {
  query: query2,
  queryHeader,
  queryBody,
  queryRow,
  fireSelect,
  fireSelectAll,
  fireExpand
};
function fireSelect(container, index) {
  const row = queryRow(container, index);
  if (!row)
    throw failedQuerySelector(`.${getProvider("prefixCls")}-table-row`);
  const ele = checkbox.query(row);
  if (!ele)
    throw failedQuerySelector(`.${getProvider("prefixCls")}-checkbox-input`);
  fireEvent.click(ele);
}
function fireSelectAll(container) {
  const header = queryHeader(container);
  if (!header)
    throw failedQuerySelector("table");
  const ele = checkbox.query(header);
  if (!ele)
    throw failedQuerySelector(`.${getProvider("prefixCls")}-checkbox-input`);
  fireEvent.click(ele);
}
function fireExpand(container, index) {
  const selectors = [
    `.${getProvider("prefixCls")}-table-row`,
    `button.${getProvider("prefixCls")}-table-row-expand-icon`
  ];
  const ele = queryViaSelectors(container, selectors, [index]);
  if (!ele)
    throw failedQuerySelector(`${selectors[0]}[${index}] ${selectors[1]}`);
  fireEvent.click(ele);
}
function query2(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-table-wrapper`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryHeader(container, index = 0) {
  const wrapper = query2(container, index);
  if (!wrapper)
    return null;
  const fixedHeader = wrapper.classList.contains(`.${getProvider("prefixCls")}-table-fixed-header`);
  const selector = fixedHeader ? `.${getProvider("prefixCls")}-table-header` : `.${getProvider("prefixCls")}-table-thead`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryBody(container, index = 0) {
  const wrapper = query2(container, index);
  if (!wrapper)
    return null;
  const fixedHeader = wrapper.classList.contains(`.${getProvider("prefixCls")}-table-fixed-header`);
  const selector = fixedHeader ? `.${getProvider("prefixCls")}-table-body` : `.${getProvider("prefixCls")}-table-tbody`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryRow(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-table-row`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireExpand,
  fireSelect,
  fireSelectAll,
  query2 as query,
  queryBody,
  queryHeader,
  queryRow
};
