// src/tabs/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import {
  failedQuerySelector,
  failedTriggerElement,
  mixinElementWithTestFuncs,
  queryViaSelector,
  queryViaSelectors
} from "../utils";
var mixins = {
  query,
  queryTabTitle,
  queryAddButton,
  queryRemoveButton,
  fireClick,
  fireChange,
  fireEdit
};
function fireClick(container, activeKey) {
  const selector = `.${getProvider("prefixCls")}-tabs-tab[data-node-key="${activeKey}"]`;
  const ele = queryTabTitle(container, activeKey);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireChange(container, activeKey) {
  fireClick(container, activeKey);
}
function fireEdit(container, action, activeKey) {
  switch (action) {
    case "add": {
      const ele = queryAddButton(container);
      if (!ele)
        throw failedQuerySelector(`.${getProvider("prefixCls")}-tabs-nav-add`);
      fireEvent.click(ele);
      break;
    }
    case "remove": {
      if (!activeKey)
        throw new Error("Remove action should specify activeKey!");
      const ele = queryRemoveButton(container, activeKey);
      if (!ele)
        throw failedTriggerElement();
      fireEvent.click(ele);
      break;
    }
    default:
      throw new Error("Invalid action for Tabs. Please ensure action between add or remove");
  }
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tabs`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryTabTitle(container, activeKey) {
  const selector = `.${getProvider("prefixCls")}-tabs-tab[data-node-key="${activeKey}"]`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryAddButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tabs-nav-add`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryRemoveButton(container, activeKey) {
  const selectors = [
    `.${getProvider("prefixCls")}-tabs-tab[data-node-key="${activeKey}"]`,
    `.${getProvider("prefixCls")}-tabs-tab-remove`
  ];
  const ele = queryViaSelectors(container, selectors, []);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireClick,
  fireEdit,
  query,
  queryAddButton,
  queryRemoveButton,
  queryTabTitle
};
