import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClose function by click close icon
 *
 * You need set `closable` attr first
 * @param titleOrIndex tag name or index
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <div>
 *         <Tag>tag1</Tag>
 *         <Tag closable onClose={fn}>
 *             tag2
 *         </Tag>
 *     </div>
 * );
 * tag.fireClose(container, 'tag2');
 * expect(fn).toHaveBeenCalled();
 */
export declare function fireClose(container: IContainer, titleOrIndex: string | number): void;
/**
 * Returns the `title` or `index` of Tag
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Tag data-testid="test1">tag1</Tag>
 *         <Tag data-testid="test2">tag2</Tag>
 *     </>
 * );
 * expect(tag.query(container, 0)).toEqual(getByTestId('test1'));
 * expect(tag.query(container, 'tag2')).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, titleOrIndex: string | number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireClose: typeof fireClose;
    }> | null | undefined;
