// src/timePicker/index.ts
import { fireEvent } from "@testing-library/react";
import * as datePicker from "../datePicker";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryDropdown: queryDropdown2,
  queryOk,
  fireOpen: fireOpen2,
  fireOk,
  fireSelectCell
};
function fireOpen2(container) {
  datePicker.fireOpen(container);
}
function fireOk(container) {
  const ele = queryOk(container);
  if (!ele)
    throw failedQuerySelector(`.${getProvider("prefixCls")}-picker-ok button`);
  fireEvent.click(ele);
}
function fireSelectCell(container, index) {
  const selector = `li.${getProvider("prefixCls")}-picker-time-panel-cell`;
  const ele = queryViaSelector(container, selector, index);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireSinglePanel(container, time) {
  const [hour, minute, second] = time.split(":");
  if (hour) {
    fireSelectCell(container.item(0), Number(hour));
  }
  if (minute) {
    fireSelectCell(container.item(1), Number(minute));
  }
  if (second) {
    fireSelectCell(container.item(2), Number(second));
  }
}
function fireChange(container, time) {
  const selector = `.${getProvider("prefixCls")}-picker-content`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  if (Array.isArray(time)) {
    fireSinglePanel(ele.children, time[0]);
    fireOk(container);
    fireSinglePanel(ele.children, time[1]);
    fireOk(container);
  } else {
    fireSinglePanel(ele.children, time);
    fireOk(container);
  }
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdown2(container) {
  datePicker.queryDropdown(container);
}
function queryOk(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-picker-ok button`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireOk,
  fireOpen2 as fireOpen,
  fireSelectCell,
  query,
  queryDropdown2 as queryDropdown,
  queryOk
};
