// src/transfer/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector, queryViaSelectors } from "../utils";
var mixins = {
  query,
  queryOperationButton,
  fireChange,
  fireScroll,
  fireSearch
};
function fireChange(container, direction) {
  const toRightBtn = queryOperationButton(container, 0);
  const toLeftBtn = queryOperationButton(container, 1);
  const btn = direction === "left" ? toLeftBtn : toRightBtn;
  if (!btn)
    throw failedQuerySelector("button");
  fireEvent.click(btn);
}
function fireScroll(container, type = "source") {
  const selectors = [
    `.${getProvider("prefixCls")}-transfer-list`,
    `.${getProvider("prefixCls")}-transfer-list-content`
  ];
  const scrollTargetIndex = type === "source" ? 0 : 1;
  const ele = queryViaSelectors(container, selectors, [scrollTargetIndex, 0]);
  if (!ele)
    throw failedQuerySelector(`${selectors[0]}[${scrollTargetIndex}] ${selectors[1]}[0]`);
  fireEvent.scroll(ele);
}
function fireSearch(container, opts) {
  const { direction, searchText } = opts;
  const selectors = [`.${getProvider("prefixCls")}-transfer-list-search`, `.${getProvider("prefixCls")}-input`];
  const searchTargetIndex = direction === "left" ? 0 : 1;
  const ele = queryViaSelectors(container, selectors, [searchTargetIndex]);
  if (!ele)
    throw failedQuerySelector(`${selectors[0]}[${searchTargetIndex}] ${selectors[1]}`);
  fireEvent.change(ele, { target: { value: searchText } });
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-transfer`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryOperationButton(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-transfer .${getProvider("prefixCls")}-transfer-operation button`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireChange,
  fireScroll,
  fireSearch,
  query,
  queryOperationButton
};
