// src/tree/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, failedQuerySelectors, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  fireCheck,
  fireExpand,
  fireRightClick,
  fireSelect,
  fireDrag
};
function fireCheck(container, title) {
  var _a, _b;
  const selector = `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${title}"]`;
  const checkbox = `.${getProvider("prefixCls")}-tree-checkbox`;
  const ele = (_b = (_a = container.querySelector(selector)) == null ? void 0 : _a.parentElement) == null ? void 0 : _b.querySelector(checkbox);
  if (!ele)
    throw failedQuerySelector(`${selector}'s parentElement ${checkbox}`);
  fireEvent.click(ele);
}
function fireExpand(container, title) {
  var _a, _b;
  const selector = `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${title}"]`;
  const switcher = `.${getProvider("prefixCls")}-tree-switcher`;
  const ele = (_b = (_a = container.querySelector(selector)) == null ? void 0 : _a.parentElement) == null ? void 0 : _b.querySelector(switcher);
  if (!ele)
    throw failedQuerySelector(`${selector}'s parentElement ${switcher}`);
  fireEvent.click(ele);
}
function fireRightClick(container, title) {
  const selector = `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${title}"]`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.contextMenu(ele);
}
function fireSelect(container, title) {
  const selector = `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${title}"]`;
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireDrag(container, sourceNodeTitle, targetNodeTitle) {
  const selectors = [
    `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${sourceNodeTitle}"]`,
    `.${getProvider("prefixCls")}-tree-node-content-wrapper[title="${targetNodeTitle}"]`
  ];
  const sourceNodeEle = queryViaSelector(container, selectors[0]);
  const targetNodeEle = queryViaSelector(container, selectors[1]);
  if (!sourceNodeEle || !targetNodeEle)
    throw failedQuerySelectors(selectors);
  fireEvent.dragStart(sourceNodeEle);
  fireEvent.dragLeave(sourceNodeEle);
  fireEvent.dragEnter(targetNodeEle);
  fireEvent.dragOver(targetNodeEle);
  fireEvent.drop(targetNodeEle);
  fireEvent.dragEnd(targetNodeEle);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tree`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireCheck,
  fireDrag,
  fireExpand,
  fireRightClick,
  fireSelect,
  query
};
