// src/treeSelect/index.ts
import { fireEvent } from "@testing-library/react";
import { getProvider } from "../provider";
import { failedQuerySelector, mixinElementWithTestFuncs, queryViaSelector } from "../utils";
var mixins = {
  query,
  queryInput,
  queryDropdown,
  queryOption,
  querySelectorWrapper,
  queryClear,
  fireOpen,
  fireSearch,
  fireSelect,
  fireTreeExpand
};
function fireOpen(container) {
  const selector = `.${getProvider("prefixCls")}-tree-select .${getProvider("prefixCls")}-select-selector`;
  const ele = querySelectorWrapper(container);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.mouseDown(ele);
}
function fireSearch(container, value) {
  const selector = "input";
  const ele = queryViaSelector(container, selector);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.change(ele, { target: { value } });
}
function fireSelect(container, index) {
  const selector = `span.${getProvider("prefixCls")}-select-tree-node-content-wrapper`;
  const ele = queryViaSelector(container, selector, index);
  if (!ele)
    throw failedQuerySelector(selector);
  fireEvent.click(ele);
}
function fireTreeExpand(container, index) {
  var _a, _b;
  const selector = `span.${getProvider("prefixCls")}-select-tree-node-content-wrapper`;
  const switcher = `.${getProvider("prefixCls")}-select-tree-switcher`;
  const ele = (_b = (_a = container.querySelectorAll(selector).item(index)) == null ? void 0 : _a.parentElement) == null ? void 0 : _b.querySelector(switcher);
  if (!ele)
    throw failedQuerySelector(`${selector}[${index}]'s parentElement ${switcher}`);
  fireEvent.click(ele);
}
function query(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tree-select`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryInput(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tree-select input.${getProvider(
    "prefixCls"
  )}-select-selection-search-input`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function querySelectorWrapper(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tree-select .${getProvider("prefixCls")}-select-selector`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryDropdown(container) {
  const selector = `.${getProvider("prefixCls")}-tree-select-dropdown:not(.${getProvider(
    "prefixCls"
  )}-select-dropdown-hidden)`;
  const ele = queryViaSelector(container, selector);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryOption(container, index = 0) {
  const selector = `span.${getProvider("prefixCls")}-select-tree-node-content-wrapper`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
function queryClear(container, index = 0) {
  const selector = `.${getProvider("prefixCls")}-tree-select .${getProvider("prefixCls")}-select-clear`;
  const ele = queryViaSelector(container, selector, index);
  return mixinElementWithTestFuncs(ele, mixins);
}
export {
  fireOpen,
  fireSearch,
  fireSelect,
  fireTreeExpand,
  query,
  queryClear,
  queryDropdown,
  queryInput,
  queryOption,
  querySelectorWrapper
};
