// src/utils/index.ts
var failedQuerySelector = (selector) => new Error(`Failed to query selector about "${selector}"`);
var failedQuerySelectors = (selectors) => new Error(`Failed to query selector neither "${selectors.join('" nor "')}"`);
var failedTriggerElement = () => new Error("Failed to trigger element for NOT found element");
function queryViaSelector(container, selector, index) {
  if (!container)
    throw new Error("container element is null");
  if (!(container instanceof Document) && container.matches(selector)) {
    return container;
  }
  if (typeof index === "number") {
    return container.querySelectorAll(selector).item(index);
  }
  return container.querySelector(selector);
}
function queryViaSelectors(container, selectors, index) {
  const i = selectors.findIndex(
    function(selector) {
      this.className += ` ${selector}`;
      return !(container instanceof Document) && !container.matches(this.className);
    },
    {
      className: ""
    }
  );
  const restSelectors = selectors.slice(i);
  const restIndex = index.slice(i);
  return restSelectors.reduce((acc, cur, idx) => {
    const queryAll = typeof restIndex[idx] === "number";
    if (queryAll) {
      return acc == null ? void 0 : acc.querySelectorAll(cur).item(restIndex[idx]);
    }
    return acc == null ? void 0 : acc.querySelector(cur);
  }, container);
}
function mixinElementWithTestFuncs(el, funcs) {
  if (!el)
    return el;
  const mixinFunctions = Object.keys(funcs);
  mixinFunctions.forEach((funcName) => {
    if (!Object.prototype.hasOwnProperty.call(el, funcName)) {
      el[funcName] = funcs[funcName].bind(this, el);
    }
  });
  return el;
}
export {
  failedQuerySelector,
  failedQuerySelectors,
  failedTriggerElement,
  mixinElementWithTestFuncs,
  queryViaSelector,
  queryViaSelectors
};
